% Intrinsic parameters:
%  Image center: 
 u0 = 378.236053; v0 = 283.902802;
% Scale factor: 
au = 1854.758789; av = 1798.011963;
% Image size: 
dimx = 768; dimy = 576;
Focal= 1;
%put everything into matrix
Mi_L=[...
    Focal*au    0           u0
    0           Focal*av    v0
    0           0           1
    ];
%The unit in camera coordinates is milimeter: 
%The opposite corners of the image, the  pixel (0 0) and (767 575), expressed as (column, row), are 
%mapped to [2.0393 1.579 1]' and  [2.096 1.619 1] in world units ( due to  inv(Mi_L)*[[0 0 1]',[767 575 1]']).
%Then the visible ccd size is [4.135 3.198]. 
%Typical commercial ccd sizes are as follows.
%2/3 inch ccd size (8.8 x 6.6 mm), 
%1/2 inch ccd size (6.4 x 4.8 mm), 
%1/3 inch ccd size (4.8 x 3.6 mm)
%Thus If the world unit of f is in mm chip size of  1/3 inch size makes sense.  

% Extrinsic parameters, Left:
% Rotation:
R_L=[[0.442128, -0.186504, 0.877348];
 [-0.015656, 0.976390, 0.215447];
 [-0.896816, -0.108991, 0.428769]]'; 
%This is transposed compared to that of left.txt. It moves a vector expressed in world
%coordinates to Camera coordinates

% Translation vector. The vector is already in the  coordinates:
%t_L=\vec{O_W O_L}
t_L=[-1348.430908, -214.044937, -945.597900]';
%To make t_R=\vec{O_L O_W },  in conformance with the convention of the book. we adjust the sign 
t_L=-R_L*t_L;

%Since \vec{O_L P} = \vec{O_L O_W } + \vec{O_W O_P }
%is valid in the SAME coordinate frame, we have to write
%\vec{P_L}= t_L+  R_L* \vec{P_W},  
%where,  P_L, t_L are  in camera coordinates
%and P_W is  in  World coordinates. Consequently:

Me_L= [R_L t_L];



% Right camera: Intrinsic parameters:
% Image center: 
u0 = 378.063263; v0 = 285.467163;
% Scale factor: 
 au = 1848.951294; av = 1795.112915;
% Image size: dimx = 768; dimy = 576;
% Focal: 1;
Mi_R=[...
    Focal*au    0           u0
    0           Focal*av    v0
    0           0           1
    ];



% Extrinsic parameters:
% Rotation:
R_R=[[0.691297, -0.151556, 0.706498];
 [-0.009506, 0.975764, 0.218620];
 [-0.722508, -0.157848, 0.673102]]'; 

%This is transposed compared to right.txt. It moves a vector expressed in world
%coordinates to Camera coordinates

%ACCEPTED Translation vector hypothesis. 
%The vector is in the world  coordinates and ponts into camera origin. The
%world coordinates and camera cordinates are aligned growth-wise. X_C,Y_C
%grow in the same direction as image points col and row, being right, down.
%t_R=\vec{O_W O_R}
t_R=[-991.766602, -212.195465, -1191.052124]'; 
%The assumption causes that all values are negative because the Z_W coordinate points into the image plane with  X_W, Y_W growing in the same direction as 
%camera X_C, Y_C  (and column and row, which are to be understood as behind the "perspective/rotated" version 
%of the physical image plane). 
t_R=-R_R*t_R; %Now, therefore,  t_R is in camera coordinates and points into O_w 
Me_R= [R_R t_R];

%That i) t_L and t_R are NOW in camera coordinates pointing into world origin (after sign change), 
%and ii) R_L and R_R transfer NOW  from world to camera coordinates 
%are verified by debugging and development code-lines in depth_by_triangulation and verification...


%REJECTED HYPOTHESIS
%1. hypothes: t_L & t_R in World coordinates pointing into O_W, R: World -> Camera
%Not working because  stereo basis vector \vec{O_RO_L} is not correctly positioned
% W    CR       W     CR
%[t_L, R_R*t_L,  t_R, R_R*t_R, R_R*t_R-R_R*t_L]

%2. hypothes: t_L & t_R in World coordinates pointing into O_W, R': World -> Camera
%Not working because  stereo basis vector \vec{O_RO_L} is not correctly positioned
% W    CR         W     CR       CR
% [t_L, R_R'*t_L,  t_R, R_R'*t_R, R_R'*t_R-R_R'*t_L]


%3 hypothes: t_L & t_R in Camera coordinates pointing into O_W, R: World -> Camera
%working because  stereo basis vector \vec{O_RO_L} is correctly positioned
% L     R             R     R    R  
%  [t_L, R_R*R_L'*t_L,  t_R,   t_R, t_R-R_R*R_L'*t_L]


%4 hypothes: t_L & t_R in Camera coordinates pointing into O_W, R': World -> Camera
%Not working because  stereo basis vector \vec{O_RO_L} is not correctly positioned
% L     R             R     R    R  
%[t_L, R_R'*R_L*t_L,  t_R,   t_R, t_R-R_R'*R_L*t_L]

